@@ -6,7 +6,40 @@ members.
 
 This extension gives also the possibility to choose which data shall be shown
 and to include the docstring of the ``'__call__'`` attribute.
+
+**Disclaimer**
+
+Copyright 2016-2019, Philipp S. Sommer
+Copyright 2020-2021, Helmholtz-Zentrum Hereon
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 """
+
+__author__ = "Philipp S. Sommer"
+__copyright__ = (
+    "2016 - 2019, Philipp S. Sommer\n"
+    "2020 - 2021, Helmholtz-Zentrum Hereon"
+)
+__credits__ = ["Philipp S. Sommer"]
+__license__ = "Apache-2.0"
+
+__maintainer__ = "Philipp S. Sommer"
+__email__ = "philipp.sommer@hereon.de"
+
+__status__ = "Production"
+
+__version__ = '0.2.5'
+
 from itertools import chain
 
 from sphinx.util import logging
@@ -31,8 +64,6 @@ from sphinx.ext.autodoc.directive import (
     DocumenterBridge
 )
 
-from sphinx.ext.autodoc import get_documenters
-
 try:
     from sphinx.util.inspect import signature, stringify_signature
 except ImportError:
@@ -56,9 +87,6 @@ except ImportError:
     except ImportError:
         from ordereddict import OrderedDict
 
-__version__ = '0.2.4'
-
-__author__ = "Philipp S. Sommer"
 
 logger = logging.getLogger(__name__)
 
@@ -199,7 +227,7 @@ class AutosummaryDocumenter(object):
 
         # document non-skipped members
         memberdocumenters = []
-        registry = get_documenters(self.env.app)
+        registry = self.env.app.registry.documenters
 
         for (mname, member, isattr) in self.filter_members(members, want_all):
             classes = [cls for cls in registry.values()
@@ -604,7 +632,7 @@ def setup(app):
          if option not in AUTODOC_DEFAULT_OPTIONS])
 
     # make sure to allow inheritance when registering new documenters
-    registry = get_documenters(app)
+    registry = app.registry.documenters
     for cls in [AutoSummClassDocumenter, AutoSummModuleDocumenter,
                 CallableAttributeDocumenter, NoDataDataDocumenter,
                 NoDataAttributeDocumenter]:
